@@ -1,10 +1,8 @@
 from pandas import DataFrame
 from sklearn.base import BaseEstimator
-try:
-	from sklearn.feature_selection._base import SelectorMixin
-except ImportError:
-	from sklearn.feature_selection.base import SelectorMixin
+from sklearn.feature_selection import SelectorMixin
 from sklearn.utils.validation import check_is_fitted
+from sklearn2pmml.util import to_numpy
 
 import numpy
 
@@ -18,10 +16,9 @@ class SelectUnique(BaseEstimator, SelectorMixin):
 		return self.support_mask_
 
 	def fit(self, X, y = None):
+		X = to_numpy(X)
 		rows, cols = X.shape
-		mask = numpy.full((cols), True, dtype = bool)
-		if isinstance(X, DataFrame):
-			X = X.values
+		mask = numpy.full((cols), fill_value = True)
 		for left in range(cols):
 			if mask[left] is False:
 				continue
